<?php

// Add Temp Mail Admin Page
if ( ! function_exists( 'wp_tm_admin_page' ) ) {
	function wp_tm_admin_page() {
		add_theme_page(
			esc_html__( 'Temp Mail X Theme', 'temp-mail-x' ),
			esc_html__( 'Temp Mail X Theme', 'temp-mail-x' ),
			'edit_theme_options',
			'wp-tm-theme',
			'wp_tm_admin_page_output'
		);
	}
}
add_action( 'admin_menu', 'wp_tm_admin_page' );

if ( ! function_exists( 'wp_tm_admin_notices' ) ) {
	/**
	 * Show admin notices
	 */
	function wp_tm_admin_notices() {
		$screen = get_current_screen();
		if ( 'appearance_page_wp_tm_theme' !== $screen->id ) {
			get_template_part( 'template-parts/admin', 'notices' );
		}
	}
}
add_action( 'admin_notices', 'wp_tm_admin_notices' );

if ( ! function_exists( 'wp_tm_dismiss_notice' ) ) {
	/**
	 * Dismiss admin notice
	 */
	function wp_tm_dismiss_notice() {
		global $current_user;

		$user_id = $current_user->ID;

		$dismiss_option = filter_input( INPUT_GET, 'wp_tm_dismiss', FILTER_SANITIZE_STRING );
		if ( is_string( $dismiss_option ) && in_array( $dismiss_option, array( 'welcome' ) ) ) {
			add_user_meta( $user_id, "wp_tm_dismissed_$dismiss_option", 'true', true );
			// delete_user_meta( $user_id, "wp_tm_dismissed_$dismiss_option", 'true', true );
			wp_die( '', '', array( 'response' => 200 ) );
		}
	}
}
add_action( 'admin_init', 'wp_tm_dismiss_notice' );

if ( ! function_exists( 'wp_tm_install_elementor_kit' ) ) {
	/**
	 * Install Elementor & Moose Elementor kit By One Click
	 */
	function wp_tm_install_elementor_kit() {
		require_once ABSPATH . 'wp-admin/admin-header.php';

		?>
        <div class="wrap">
			<?php
			wp_tm_do_install_plugins( [
				'elementor'           => esc_html__( 'Elementor', 'temp-mail-x' ),
				'moose-elementor-kit' => esc_html__( 'Moose Elementor Kit', 'temp-mail-x' )
			] );
			?>
        </div>
		<?php
	}
}
add_action( 'admin_action_wp_tm_install_elementor_kit', 'wp_tm_install_elementor_kit' );

if ( ! function_exists( 'wp_tm_install_temp_mail' ) ) {
	/**
	 * Install Temp Mail Plugin By One Click
	 */
	function wp_tm_install_temp_mail() {
		require_once ABSPATH . 'wp-admin/admin-header.php';

		?>
        <div class="wrap">
			<?php
			wp_tm_do_install_plugins( [
				'temp-mail' => esc_html__( 'WP Temp Mail', 'temp-mail-x' ),
			] );
			?>
        </div>
		<?php
	}
}
add_action( 'admin_action_wp_tm_install_temp_mail', 'wp_tm_install_temp_mail' );

if ( ! function_exists( 'wp_tm_admin_page_output' ) ) {
	/**
	 * Show admin welcome page
	 */
	function wp_tm_admin_page_output() {
		get_template_part( 'template-parts/admin', 'welcome' );
	}
}
