<?php
/**
 * Customizer Control: wp-tm-tabs
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( class_exists( 'TempMail_Customize_Control' ) && ! class_exists( 'TempMail_Tabs_Customize_Control' ) ) {
	/**
	 * Tabs control
	 */
	class TempMail_Tabs_Customize_Control extends TempMail_Customize_Control {
		/**
		 * Set the control type.
		 *
		 * @var string $type
		 */
		public $type = 'wp-tm-tabs';

		/**
		 * The default active tab id.
		 *
		 * @var string
		 */
		public $default_tab;

		/**
		 * The tabs with keys of the controls that are under each tab.
		 *
		 * @var array
		 */
		public $tabs;

		/**
		 * Controls from tabs.
		 *
		 * @var array
		 */
		public $controls;

		/**
		 * Refresh the parameters passed to the JavaScript via JSON.
		 *
		 * @see WP_Customize_Control::to_json()
		 */
		public function json() {
			$json                = parent::json();
			$json['default_tab'] = $this->default_tab;
			$json['tabs']        = $this->tabs;
			$json['controls']    = $this->controls;

			return $json;
		}

		/**
		 * An Underscore (JS) template for this control's content (but not its container).
		 *
		 * Class variables for this control class are available in the `data` JS object;
		 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
		 *
		 * @return void
		 * @see WP_Customize_Control::print_template()
		 * @since 1.0.0
		 */
		public function content_template() {
			?>
            <# if ( ! data.tabs ) { return; } #>
            <div class="wp-tm-tabs-control">
                <# for( tab in data.tabs) { #>
                <div class="wp-tm-customizer-tab <# if( tab === data.default_tab ){#> active <#}#>" data-tab="{{tab}}">
                    <label class="">
                        <# if( data.tabs[tab]['icon'] ) { #>
                        <span class="dashicons dashicons-{{data.tabs[tab]['icon']}}"></span>
                        <# } #>
                        {{data.tabs[tab]['label']}}
                    </label>
                </div>
                <# } #>
            </div>
			<?php
		}
	}
}
