<?php

function get_wp_tm_default_colors()
{
    return array();
}

if ( !function_exists( 'wp_tm_register_colors_options' ) ) {
    /**
     * Add colors section and controls.
     *
     * @param \WP_Customize_Manager $wp_customize
     */
    function wp_tm_register_colors_options( $wp_customize, $section_id )
    {
        // Register out color settings
        foreach ( get_wp_tm_default_colors() as $id => $arg ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_' . $id,
                'label'          => $arg['label'],
                'setting'        => array(
                'default'           => $arg['default'],
                'sanitize_callback' => 'sanitize_hex_color',
            ),
                'section'        => $section_id,
                'custom_control' => \WP_Customize_Color_Control::class,
            ) );
        }
        wp_tm_go_to_upsell(
            $wp_customize,
            $section_id,
            'wp_tm_colors_go_to_upsell',
            esc_html__( 'Want More Colors? See Temp Mail Pro', 'temp-mail-x' )
        );
    }

}
if ( !function_exists( 'get_wp_tm_color' ) ) {
    /**
     * Get custom color value.
     *
     * @param string $color_name
     *
     * @return string
     */
    function get_wp_tm_color( $color_name )
    {
        $defaults = get_wp_tm_default_colors();
        
        if ( isset( $defaults[$color_name] ) ) {
            $color = wp_tm_get_theme_mod( 'wp_tm_' . $color_name, $defaults[$color_name]['default'] );
        } else {
            $color = wp_tm_get_theme_mod( 'wp_tm_' . $color_name );
        }
        
        return apply_filters( 'wp_tm_filter_color_' . $color_name, $color );
    }

}
if ( !function_exists( 'get_wp_tm_color_rgb_value' ) ) {
    /**
     * Get custom color in rgb value
     *
     * @param $color_name
     *
     * @return string
     */
    function get_wp_tm_color_rgb_value( $color_name )
    {
        list( $r, $g, $b ) = wp_tm_hex_to_rgb( get_wp_tm_color( $color_name ) );
        return $r . ',' . $g . ',' . $b;
    }

}