<?php

if ( !function_exists( 'wp_tm_register_posts_options' ) ) {
    /**
     * Add posts options and controls.
     *
     * @param \WP_Customize_Manager $wp_customize
     * @param string $section_id
     * @param int $priority
     */
    function wp_tm_register_posts_options( $wp_customize, $section_id, $priority = 100 )
    {
        $wp_customize->add_section( $section_id, array(
            'title'    => esc_html__( 'Archive Settings', 'temp-mail-x' ),
            'panel'    => '',
            'priority' => $priority,
        ) );
        if ( wp_tm_fs()->is_not_paying() ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_posts_structure_upsell_tips',
                'section'        => $section_id,
                'settings'       => array(),
                'custom_control' => TempMail_Info_Customize_Control::class,
                'control_args'   => array(
                'messages' => array(
                esc_html__( 'In our Pro version, you can get:', 'temp-mail-x' ),
                array(
                esc_html__( 'Grid layout', 'temp-mail-x' ),
                esc_html__( 'Adjust post item structure', 'temp-mail-x' ),
                esc_html__( 'Adjust metas content and order', 'temp-mail-x' ),
                esc_html__( 'Show hero in archive page', 'temp-mail-x' ),
                esc_html__( 'Different header style in archive page', 'temp-mail-x' ),
                esc_html__( 'Additional button styles', 'temp-mail-x' ),
                esc_html__( 'Additional pagination styles', 'temp-mail-x' )
            ),
                sprintf( '<a href="%1$s" target="_blank">%2$s</a>', wp_tm_upsell_url(), __( 'Meet Temp Mail Theme Pro', 'temp-mail-x' ) ),
                array( sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://vimeo.com/692558052', __( 'Customize Archive Video Tutorial', 'temp-mail-x' ) ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://vimeo.com/692558029', __( 'Archive Hero Video Tutorial', 'temp-mail-x' ) ) )
            ),
            ),
            ) );
        }
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_posts_layout_and_content',
            'section'        => $section_id,
            'settings'       => array(),
            'custom_control' => TempMail_Heading_Customize_Control::class,
            'control_args'   => array(
            'title' => esc_html__( 'LAYOUT & CONTENT', 'temp-mail-x' ),
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_posts_layout',
            'label'          => esc_html__( 'Posts Layout', 'temp-mail-x' ),
            'choices'        => wp_tm_get_archive_layout_options(),
            'section'        => $section_id,
            'custom_control' => TempMail_Image_Radio_Button_Customize_Control::class,
            'control_args'   => array(
            'should_init' => true,
            'subcontrols' => array(
            'archive-grid'  => array( 'wp_tm_grid_layout_columns', 'wp_tm_grid_layout_upsell_tips' ),
            'archive-left'  => array( 'wp_tm_archive_list_layout_image_width' ),
            'archive-right' => array( 'wp_tm_archive_list_layout_image_width' ),
        ),
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_archive_list_layout_image_width',
            'label'          => esc_html__( 'Feature Image Width', 'temp-mail-x' ),
            'description'    => esc_html__( '"0" means use the default value', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Slider_Customize_Control::class,
            'choices'        => array(
            'desktop' => array(
            'min'  => 0,
            'max'  => 75,
            'step' => 1,
            'unit' => '%',
        ),
        ),
            'settings'       => array(
            'desktop' => 'wp_tm_archive_list_layout_image_width',
        ),
        ) );
        if ( wp_tm_fs()->is_not_paying() ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_grid_layout_upsell_tips',
                'section'        => $section_id,
                'settings'       => array(),
                'custom_control' => TempMail_Info_Customize_Control::class,
                'control_args'   => array(
                'messages' => array( esc_html__( 'In our Pro version, you can set different grid columns count for pc, tablet and mobile.', 'temp-mail-x' ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', wp_tm_upsell_url(), __( 'Meet Temp Mail Theme Pro', 'temp-mail-x' ) ) ),
            ),
            ) );
        }
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_layout_divider',
            'section'        => $section_id,
            'settings'       => array(),
            'custom_control' => TempMail_Divider_Customize_Control::class,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_show_archive_feature_image',
            'label'          => esc_html__( 'Show Feature Image', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Switch_Customize_Control::class,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'        => 'wp_tm_excerpt_length',
            'label'       => esc_html__( 'Excerpt length (words)', 'temp-mail-x' ),
            'type'        => 'number',
            'section'     => $section_id,
            'input_attrs' => array(
            'min'  => 10,
            'max'  => 200,
            'step' => 5,
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_read_more_text',
            'label'   => esc_html__( 'Read More Text', 'temp-mail-x' ),
            'type'    => 'text',
            'section' => $section_id,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_posts_style',
            'section'        => $section_id,
            'settings'       => array(),
            'custom_control' => TempMail_Heading_Customize_Control::class,
            'control_args'   => array(
            'title' => esc_html__( 'STYLE', 'temp-mail-x' ),
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_button_style',
            'label'   => esc_html__( 'Button Style', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_button_style_options(),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_pagination_style',
            'label'   => esc_html__( 'Pagination Style', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_button_style_options(),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_pagination_type',
            'label'   => esc_html__( 'Pagination Type', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_pagination_options(),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_is_outline_pagination',
            'label'          => esc_html__( 'Pagination Outline', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Switch_Customize_Control::class,
        ) );
    }

}
if ( !function_exists( 'get_wp_tm_grid_layout_columns' ) ) {
    /**
     * Get grid layout columns count
     *
     * @param $device
     *
     * @return mixed|void
     */
    function get_wp_tm_grid_layout_columns( $device )
    {
        return get_wp_tm_option( 'wp_tm_grid_layout_columns_' . $device );
    }

}
if ( !function_exists( 'get_wp_tm_grid_layout_columns_style' ) ) {
    /**
     * Get grid layout columns css class names
     *
     * @return string
     */
    function get_wp_tm_grid_layout_columns_style()
    {
        if ( function_exists( 'get_wp_tm_grid_layout_columns_style__premium_only' ) ) {
            return get_wp_tm_grid_layout_columns_style__premium_only();
        }
        return '';
    }

}
if ( !function_exists( 'get_wp_tm_button_style' ) ) {
    /**
     * Return css class for button
     *
     * @return string
     */
    function get_wp_tm_button_style()
    {
        return wp_tm_get_button_style_css( get_wp_tm_option( 'wp_tm_button_style' ) );
    }

}
if ( !function_exists( 'wp_tm_button_style' ) ) {
    /**
     * Output css class for button
     */
    function wp_tm_button_style()
    {
        echo  get_wp_tm_button_style() ;
    }

}
if ( !function_exists( 'get_wp_tm_pagination_style' ) ) {
    /**
     * Return css class for pagination
     *
     * @return string
     */
    function get_wp_tm_pagination_style()
    {
        $style = get_wp_tm_option( 'wp_tm_pagination_style' );
        $is_outline = get_wp_tm_option( 'wp_tm_is_outline_pagination' );
        $css = wp_tm_get_button_style_css( $style );
        if ( $is_outline ) {
            $css .= ' btn-outline';
        }
        return $css;
    }

}
if ( !function_exists( 'wp_tm_pagination_style' ) ) {
    /**
     * Output css class for pagination
     */
    function wp_tm_pagination_style()
    {
        echo  get_wp_tm_pagination_style() ;
    }

}