<?php

if ( !function_exists( 'wp_tm_register_footer_options' ) ) {
    /**
     * Add footer options and controls.
     *
     * @param \WP_Customize_Manager $wp_customize
     * @param string $section_id
     * @param int $priority
     */
    function wp_tm_register_footer_options( $wp_customize, $section_id, $priority = 100 )
    {
        $wp_customize->add_section( $section_id, array(
            'title'    => esc_html__( 'Footer Settings', 'temp-mail-x' ),
            'panel'    => '',
            'priority' => $priority,
        ) );
        wp_tm_go_to_upsell(
            $wp_customize,
            $section_id,
            'wp_tm_footer_go_to_upsell',
            esc_html__( 'Want More Footer Options? See Temp Mail Pro', 'temp-mail-x' )
        );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_copyright_text',
            'label'   => esc_html__( 'Copyright Text', 'temp-mail-x' ),
            'section' => $section_id,
            'type'    => 'text',
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_footer_style',
            'label'   => esc_html__( 'Footer Style', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_footer_style_options(),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_show_to_top',
            'label'          => esc_html__( 'Show To Top Button', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Switch_Customize_Control::class,
        ) );
    }

}
if ( !function_exists( 'get_wp_tm_footer_style' ) ) {
    /**
     * Return css class for footer
     *
     * @return string
     */
    function get_wp_tm_footer_style()
    {
        return wp_tm_get_footer_style_css( get_wp_tm_option( 'wp_tm_footer_style' ) );
    }

}
if ( !function_exists( 'wp_tm_footer_style' ) ) {
    /**
     * Output css class for footer
     */
    function wp_tm_footer_style()
    {
        echo  get_wp_tm_footer_style() ;
    }

}