<?php

if ( !function_exists( 'wp_tm_register_hero_options' ) ) {
    /**
     * Add hero section and controls.
     *
     * @param WP_Customize_Manager $wp_customize
     */
    function wp_tm_register_hero_options( $wp_customize, $section_id, $priority = 100 )
    {
        $wp_customize->add_section( $section_id, array(
            'title'    => esc_html__( 'Hero', 'temp-mail-x' ),
            'panel'    => 'wp_tm_frontpage_panel',
            'priority' => $priority,
        ) );
        $shape_divider_controls = array(
            'wp_tm_hero_shape_divider',
            'wp_tm_hero_shape_upsell',
            'wp_tm_hero_shape_color',
            'wp_tm_hero_shape_width',
            'wp_tm_hero_shape_height',
            'wp_tm_hero_shape_flip',
            'wp_tm_hero_shape_invert'
        );
        $particles_controls = array();
        $background_controls = array(
            'solid-color'    => array_merge( array(
            'wp_tm_hero_background_color',
            'wp_tm_hero_particles_heading',
            'wp_tm_hero_particles_upsell',
            'wp_tm_hero_shape_heading'
        ), $particles_controls, $shape_divider_controls ),
            'gradient-color' => array_merge( array(
            'wp_tm_hero_background_gradient',
            'wp_tm_hero_particles_heading',
            'wp_tm_hero_particles_upsell',
            'wp_tm_hero_shape_heading'
        ), $particles_controls, $shape_divider_controls ),
            'image'          => array_merge( array(
            'wp_tm_hero_background_image',
            'wp_tm_hero_background_mask',
            'wp_tm_hero_background_position',
            'wp_tm_hero_background_image_size',
            'wp_tm_hero_background_image_repeat',
            'wp_tm_hero_background_image_scroll',
            'wp_tm_hero_particles_heading',
            'wp_tm_hero_particles_upsell',
            'wp_tm_hero_shape_heading'
        ), $particles_controls, $shape_divider_controls ),
        );
        $content_controls = array(
            'simple'  => array(
            'wp_tm_hero_content_color',
            'wp_tm_hero_content_highlight_color',
            'wp_tm_hero_content_alignment',
            'wp_tm_hero_title',
            'wp_tm_hero_title_highlight',
            'wp_tm_hero_button_primary_text',
            'wp_tm_hero_button_primary_url',
            'wp_tm_hero_button_secondary_text',
            'wp_tm_hero_button_secondary_url',
            'wp_tm_hero_button_style'
        ),
            'mailbox' => array(
            'wp_tm_hero_show_mailbox_controls',
            'wp_tm_hero_content_color',
            'wp_tm_hero_content_highlight_color',
            'wp_tm_hero_title',
            'wp_tm_hero_title_highlight',
            'wp_tm_hero_subtitle'
        ),
        );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_tabs',
            'settings'       => array(),
            'section'        => $section_id,
            'custom_control' => TempMail_Tabs_Customize_Control::class,
            'control_args'   => array(
            'default_tab' => 'background',
            'tabs'        => array(
            'background' => array(
            'label' => esc_html__( 'Background', 'temp-mail-x' ),
            'icon'  => 'format-image',
        ),
            'content'    => array(
            'label' => esc_html__( 'Content', 'temp-mail-x' ),
            'icon'  => 'text',
        ),
        ),
            'controls'    => array(
            'background' => array(
            'wp_tm_hero_background_type' => $background_controls,
        ),
            'content'    => array(
            'wp_tm_hero_content_type' => $content_controls,
        ),
        ),
        ),
        ) );
        /**
         * Background options
         */
        // background type
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_background_type',
            'label'          => esc_html__( 'Background Type', 'temp-mail-x' ),
            'choices'        => wp_tm_get_hero_background_types(),
            'section'        => $section_id,
            'custom_control' => TempMail_Select_Customize_Control::class,
            'control_args'   => array(
            'subcontrols' => $background_controls,
            'should_init' => false,
        ),
        ) );
        // background color
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_background_color',
            'label'          => esc_html__( 'Background Color', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => WP_Customize_Color_Control::class,
        ) );
        /**
         * background particles
         */
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_particles_heading',
            'section'        => $section_id,
            'settings'       => array(),
            'custom_control' => TempMail_Heading_Customize_Control::class,
            'control_args'   => array(
            'title'         => esc_html__( 'PARTICLES', 'temp-mail-x' ),
            'items'         => $particles_controls,
            'default_state' => 'close',
        ),
        ) );
        if ( wp_tm_fs()->is_not_paying() ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_hero_particles_upsell',
                'section'        => $section_id,
                'settings'       => array(),
                'custom_control' => TempMail_Info_Customize_Control::class,
                'control_args'   => array(
                'messages' => array( esc_html__( 'Want background particles effect ?', 'temp-mail-x' ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', wp_tm_upsell_url(), __( 'Meet Temp Mail Theme Pro', 'temp-mail-x' ) ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://vimeo.com/692557992', __( 'View Video Demo', 'temp-mail-x' ) ) ),
            ),
            ) );
        }
        /**
         * background shape divider
         */
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_heading',
            'section'        => $section_id,
            'settings'       => array(),
            'custom_control' => TempMail_Heading_Customize_Control::class,
            'control_args'   => array(
            'title'         => esc_html__( 'SHAPE DIVIDER', 'temp-mail-x' ),
            'items'         => $shape_divider_controls,
            'default_state' => 'close',
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_divider',
            'label'          => esc_html__( 'Shape Divider', 'temp-mail-x' ),
            'section'        => $section_id,
            'choices'        => wp_tm_array_pluck( 'title', wp_tm_get_shapes() ),
            'custom_control' => TempMail_Select_Customize_Control::class,
            'control_args'   => array(
            'subcontrols' => wp_tm_array_pluck( 'options', wp_tm_get_shapes() ),
            'should_init' => false,
        ),
        ) );
        if ( wp_tm_fs()->is_not_paying() ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_hero_shape_upsell',
                'section'        => $section_id,
                'settings'       => array(),
                'custom_control' => TempMail_Info_Customize_Control::class,
                'control_args'   => array(
                'messages' => array( esc_html__( 'Want unlock more Shape Dividers ?', 'temp-mail-x' ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', wp_tm_upsell_url(), __( 'Meet Temp Mail Theme Pro', 'temp-mail-x' ) ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://vimeo.com/692557992', __( 'Shape Divider Video Tutorial', 'temp-mail-x' ) ) ),
            ),
            ) );
        }
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_color',
            'label'          => esc_html__( 'Shape Color', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => WP_Customize_Color_Control::class,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_width',
            'label'          => esc_html__( 'Width', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Slider_Customize_Control::class,
            'settings'       => array(
            'desktop' => 'wp_tm_hero_shape_width',
        ),
            'choices'        => array(
            'desktop' => array(
            'min'  => 100,
            'max'  => 500,
            'step' => 1,
            'unit' => '%',
        ),
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_height',
            'label'          => esc_html__( 'Height', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Slider_Customize_Control::class,
            'settings'       => array(
            'desktop' => 'wp_tm_hero_shape_height',
        ),
            'choices'        => array(
            'desktop' => array(
            'min'  => 0,
            'max'  => 200,
            'step' => 1,
            'unit' => 'px',
        ),
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_flip',
            'label'          => esc_html__( 'Flip', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Switch_Customize_Control::class,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_shape_invert',
            'label'          => esc_html__( 'Invert', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Switch_Customize_Control::class,
        ) );
        /**
         * Content options
         */
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_content_type',
            'label'          => esc_html__( 'Content Type', 'temp-mail-x' ),
            'choices'        => wp_tm_get_hero_content_type(),
            'section'        => $section_id,
            'custom_control' => TempMail_Select_Customize_Control::class,
            'control_args'   => array(
            'subcontrols' => $content_controls,
            'should_init' => false,
        ),
        ) );
        // mailbox controls
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_show_mailbox_controls',
            'label'          => esc_html__( 'Show Mailbox Controls', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Switch_Customize_Control::class,
        ) );
        // content color
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_hero_content_color',
            'label'          => esc_html__( 'Content Color', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => WP_Customize_Color_Control::class,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_hero_content_alignment',
            'label'   => esc_html__( 'Alignment', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_text_align_options(),
        ) );
        $simple_content_settings = array(
            'wp_tm_hero_title'                 => esc_html__( 'Title', 'temp-mail-x' ),
            'wp_tm_hero_title_highlight'       => esc_html__( 'Highlight', 'temp-mail-x' ),
            'wp_tm_hero_subtitle'              => esc_html__( 'Subtitle', 'temp-mail-x' ),
            'wp_tm_hero_button_primary_text'   => esc_html__( 'Primary Button Text', 'temp-mail-x' ),
            'wp_tm_hero_button_primary_url'    => esc_html__( 'Primary Button URL', 'temp-mail-x' ),
            'wp_tm_hero_button_secondary_text' => esc_html__( 'Secondary Button Text', 'temp-mail-x' ),
            'wp_tm_hero_button_secondary_url'  => esc_html__( 'Secondary Button URL', 'temp-mail-x' ),
        );
        foreach ( $simple_content_settings as $id => $label ) {
            wp_tm_register_options( $wp_customize, array(
                'name'    => $id,
                'label'   => $label,
                'section' => $section_id,
                'type'    => 'text',
            ) );
        }
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_hero_button_style',
            'label'   => esc_html__( 'Button Style', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_button_style_options(),
        ) );
    }

}
if ( !function_exists( 'get_wp_tm_hero_content_style' ) ) {
    function get_wp_tm_hero_content_style()
    {
        $color = get_wp_tm_option( 'wp_tm_hero_content_color' );
        return "color: {$color}";
    }

}
if ( !function_exists( 'get_wp_tm_hero_button_style' ) ) {
    /**
     * Return css class for button in the hero section
     *
     * @return string
     */
    function get_wp_tm_hero_button_style()
    {
        return wp_tm_get_button_style_css( get_wp_tm_option( 'wp_tm_hero_button_style' ) );
    }

}
if ( !function_exists( 'get_wp_tm_hero_background_style' ) ) {
    /**
     * Return inline styles for the background in the hero section
     *
     * @return string
     */
    function get_wp_tm_hero_background_style()
    {
        $color = get_wp_tm_option( 'wp_tm_hero_background_color' );
        return "background-color: {$color}";
    }

}
if ( !function_exists( 'get_wp_tm_hero_mask_style' ) ) {
    /**
     * Return inline styles for the mask in the hero section
     *
     * @return string
     */
    function get_wp_tm_hero_mask_style()
    {
        $type = get_wp_tm_option( 'wp_tm_hero_background_type' );
        if ( $type !== 'image' ) {
            return 'display: none';
        }
        return 'background-color: ' . get_wp_tm_option( 'wp_tm_hero_background_mask' );
    }

}