<?php

if ( !function_exists( 'wp_tm_register_header_options' ) ) {
    /**
     * Add header options and controls.
     *
     * @param \WP_Customize_Manager $wp_customize
     * @param string $section_id
     * @param int $priority
     */
    function wp_tm_register_header_options( $wp_customize, $section_id, $priority = 100 )
    {
        $wp_customize->add_section( $section_id, array(
            'title'    => esc_html__( 'Header Settings', 'temp-mail-x' ),
            'panel'    => '',
            'priority' => $priority,
        ) );
        if ( wp_tm_fs()->is_not_paying() ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_navbar_upsell_tips',
                'section'        => $section_id,
                'settings'       => array(),
                'custom_control' => TempMail_Info_Customize_Control::class,
                'control_args'   => array(
                'messages' => array( esc_html__( 'In our Pro version, you can:', 'temp-mail-x' ), array( esc_html__( 'Have 3 additional preset header styles', 'temp-mail-x' ), esc_html__( 'Have 3 additional preset menu styles', 'temp-mail-x' ), esc_html__( 'Fully customize your header', 'temp-mail-x' ) ), sprintf( '<a href="%1$s" target="_blank">%2$s</a>', wp_tm_upsell_url(), __( 'Meet Temp Mail Theme Pro', 'temp-mail-x' ) ) ),
            ),
            ) );
        }
        $custom_controls = array(
            'custom' => '',
        );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_header_style',
            'label'          => esc_html__( 'Header Style', 'temp-mail-x' ),
            'section'        => $section_id,
            'choices'        => wp_tm_get_header_style_options(),
            'custom_control' => TempMail_Select_Customize_Control::class,
            'control_args'   => array(
            'subcontrols' => $custom_controls,
            'should_init' => true,
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'    => 'wp_tm_menu_style',
            'label'   => esc_html__( 'Header Menu Style', 'temp-mail-x' ),
            'type'    => 'select',
            'section' => $section_id,
            'choices' => wp_tm_get_menu_style_options(),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_sticky_header',
            'label'          => esc_html__( 'Sticky Header', 'temp-mail-x' ),
            'custom_control' => TempMail_Switch_Customize_Control::class,
            'section'        => $section_id,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_header_brand',
            'label'          => esc_html__( 'Show Header Logo', 'temp-mail-x' ),
            'custom_control' => TempMail_Switch_Customize_Control::class,
            'section'        => $section_id,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_show_header_title',
            'label'          => esc_html__( 'Show Site Title', 'temp-mail-x' ),
            'custom_control' => TempMail_Switch_Customize_Control::class,
            'section'        => $section_id,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_show_header_tagline',
            'label'          => esc_html__( 'Show Tagline', 'temp-mail-x' ),
            'custom_control' => TempMail_Switch_Customize_Control::class,
            'section'        => $section_id,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_show_header_search',
            'label'          => esc_html__( 'Show Search', 'temp-mail-x' ),
            'custom_control' => TempMail_Switch_Customize_Control::class,
            'section'        => $section_id,
        ) );
    }

}
if ( !function_exists( 'get_wp_tm_header_style' ) ) {
    /**
     * Return css class for header style
     *
     * @return string
     */
    function get_wp_tm_header_style()
    {
        return wp_tm_get_header_style_css( get_wp_tm_option( 'wp_tm_header_style' ) );
    }

}
if ( !function_exists( 'get_wp_tm_header_menu_style' ) ) {
    /**
     * Return css class for header menu style
     *
     * @return string
     */
    function get_wp_tm_header_menu_style()
    {
        return wp_tm_get_header_menu_style_css( get_wp_tm_option( 'wp_tm_header_style' ), get_wp_tm_option( 'wp_tm_menu_style' ) );
    }

}
if ( !function_exists( 'wp_tm_header_style' ) ) {
    /**
     * Output css class for header style
     */
    function wp_tm_header_style()
    {
        echo  get_wp_tm_header_style() ;
    }

}