<?php

if ( !function_exists( 'wp_tm_register_single_post_options' ) ) {
    /**
     * Add single post options and controls.
     *
     * @param \WP_Customize_Manager $wp_customize
     * @param string $section_id
     * @param int $priority
     */
    function wp_tm_register_single_post_options( $wp_customize, $section_id, $priority = 100 )
    {
        $wp_customize->add_section( $section_id, array(
            'title'    => esc_html__( 'Single Post Settings', 'temp-mail-x' ),
            'panel'    => '',
            'priority' => $priority,
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_single_post_structure',
            'label'          => esc_html__( 'Post Structure', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Sortable_Customize_Control::class,
            'choices'        => array(
            'title-metas'    => array(
            'label' => esc_html__( 'Title & Metas', 'temp-mail-x' ),
        ),
            'content'        => array(
            'label' => esc_html__( 'Content', 'temp-mail-x' ),
        ),
            'category'       => array(
            'label' => esc_html__( 'Category', 'temp-mail-x' ),
        ),
            'featured-image' => array(
            'label' => esc_html__( 'Featured Image', 'temp-mail-x' ),
        ),
        ),
        ) );
        wp_tm_register_options( $wp_customize, array(
            'name'           => 'wp_tm_single_post_metas',
            'label'          => esc_html__( 'Post Metas', 'temp-mail-x' ),
            'section'        => $section_id,
            'custom_control' => TempMail_Sortable_Customize_Control::class,
            'choices'        => array(
            'comments'  => array(
            'label' => esc_html__( 'Comments', 'temp-mail-x' ),
        ),
            'byline'    => array(
            'label' => esc_html__( 'Byline', 'temp-mail-x' ),
        ),
            'posted_on' => array(
            'label' => esc_html__( 'Posted On', 'temp-mail-x' ),
        ),
            'tags'      => array(
            'label' => esc_html__( 'Tags', 'temp-mail-x' ),
        ),
            'views'     => array(
            'label'       => esc_html__( 'Views', 'temp-mail-x' ),
            'disabled'    => !function_exists( 'pvc_get_post_views' ),
            'description' => ( function_exists( 'pvc_get_post_views' ) ? '' : esc_html__( 'Post Views Counter plugin is required', 'temp-mail-x' ) ),
        ),
        ),
        ) );
        if ( wp_tm_fs()->is_not_paying() ) {
            wp_tm_register_options( $wp_customize, array(
                'name'           => 'wp_tm_lightbox_upsell_tips',
                'section'        => $section_id,
                'settings'       => array(),
                'custom_control' => TempMail_Info_Customize_Control::class,
                'control_args'   => array(
                'messages' => array( sprintf( '<a href="%1$s" target="_blank">%2$s</a>', wp_tm_upsell_url(), __( 'Lightbox Effect In Temp Mail Pro', 'temp-mail-x' ) ) ),
            ),
            ) );
        }
    }

}