<?php

if ( ! function_exists( 'wp_tm_deregister_style' ) ) {
	/**
	 * Dequeue temp mail style
	 */
	function wp_tm_deregister_style() {
		wp_deregister_style( 'temp-mail-style' );
	}
}
add_action( 'wp_enqueue_scripts', 'wp_tm_deregister_style', 9999 );
add_filter( 'tm_should_add_frontend_css', '__return_false' );

/**
 * Mailbox css
 */

if ( ! function_exists( 'wp_tm_add_mailbox_css' ) ) {
	function wp_tm_add_mailbox_css( $css ) {
		return array_merge( $css, [
			'flex',
			'justify-center',
			'items-stretch'
		] );
	}
}
add_filter( 'tm_mailbox_css', 'wp_tm_add_mailbox_css' );

if ( ! function_exists( 'wp_tm_add_email_input_css' ) ) {
	function wp_tm_add_email_input_css( $css ) {
		return array_merge( $css, [
			'bg-[#fff]/20',
			'px-4',
			'py-1',
			'font-mono',
			'flex',
			'justify-center',
			'items-center',
			'lg:min-w-[18rem]'
		] );
	}
}
add_filter( 'tm_email_input_css', 'wp_tm_add_email_input_css' );

if ( ! function_exists( 'wp_tm_add_copy_to_clipboard_button_css' ) ) {
	function wp_tm_add_copy_to_clipboard_button_css( $css ) {
		return array_merge( $css, [
			'btn',
			'btn-primary',
			'fill-primary-content',
			'p-3'
		] );
	}
}
add_filter( 'tm_copy_to_clipboard_button_css', 'wp_tm_add_copy_to_clipboard_button_css' );

/**
 * Controls css
 */

if ( ! function_exists( 'wp_tm_add_controls_wrap_css' ) ) {
	function wp_tm_add_controls_wrap_css( $css ) {
		return array_merge( $css, [
			'mt-double-gutter'
		] );
	}
}
add_filter( 'tm_controls_wrap_css', 'wp_tm_add_controls_wrap_css' );

if ( ! function_exists( 'wp_tm_add_controls_css' ) ) {
	function wp_tm_add_controls_css( $css ) {
		return array_merge( $css, [
			'flex',
			'flex-col',
			'md:flex-row',
			'justify-center',
			'items-center',
			'space-y-gutter',
			'md:space-y-0',
			'md:space-x-gutter',
		] );
	}
}
add_filter( 'tm_controls_css', 'wp_tm_add_controls_css' );

if ( ! function_exists( 'wp_tm_add_control_button_css' ) ) {
	function wp_tm_add_control_button_css( $css ) {
		return array_merge( $css, [
			'text-center',
			'w-[18rem]',
			'md:w-auto',
			'bg-[#fff]/10',
			'hover:bg-primary-focus',
			'hover:text-primary-content',
			'px-double-gutter',
			'py-half-gutter',
			'border-none',
		] );
	}
}
add_filter( 'tm_control_button_css', 'wp_tm_add_control_button_css' );

if ( ! function_exists( 'wp_tm_add_change_mailbox_form_css' ) ) {
	function wp_tm_add_change_mailbox_form_css( $css ) {
		return array_merge( $css, [
			'flex',
			'justify-center',
			'items-stretch',
			'space-x-half-gutter',
			'mt-gutter'
		] );
	}
}
add_filter( 'tm_change_mailbox_form_css', 'wp_tm_add_change_mailbox_form_css' );

if ( ! function_exists( 'wp_tm_add_change_mailbox_input_css' ) ) {
	function wp_tm_add_change_mailbox_input_css( $css ) {
		return array_merge( $css, [
			'bg-[#fff]/10',
			'border-none',
			'placeholder:text-[#fff]/20',
			'focus:outline-1 focus:outline-offset-0 focus:outline-primary focus:outline-dashed',
			'focus:ring-0',
		] );
	}
}
add_filter( 'tm_change_mailbox_id_input_css', 'wp_tm_add_change_mailbox_input_css' );
add_filter( 'tm_change_mailbox_domain_select_css', 'wp_tm_add_change_mailbox_input_css' );

if ( ! function_exists( 'wp_tm_add_change_mailbox_save_button_css' ) ) {
	function wp_tm_add_change_mailbox_save_button_css( $css ) {
		return array_merge( array_diff( $css, [ 'px-double-gutter', 'py-half-gutter' ] ), [
			'px-gutter',
			'w-auto',
		] );
	}
}
add_filter( 'tm_change_mailbox_save_button_css', 'wp_tm_add_control_button_css' );
add_filter( 'tm_change_mailbox_save_button_css', 'wp_tm_add_change_mailbox_save_button_css' );

/**
 * Inbox css
 */

if ( ! function_exists( 'wp_tm_add_inbox_css' ) ) {
	function wp_tm_add_inbox_css( $css ) {
		return array_merge( $css, [
			'w-full'
		] );
	}
}
add_filter( 'tm_inbox_css', 'wp_tm_add_inbox_css' );

if ( ! function_exists( 'wp_tm_add_inbox_header_css' ) ) {
	function wp_tm_add_inbox_header_css( $css ) {
		return array_merge( $css, [
			'bg-accent',
			'border',
			'border-solid',
			'border-accent',
			'text-accent-content',
		] );
	}
}
add_filter( 'tm_inbox_header_css', 'wp_tm_add_inbox_header_css' );

if ( ! function_exists( 'wp_tm_add_inbox_header_col_css' ) ) {
	function wp_tm_add_inbox_header_col_css( $css ) {
		return array_merge( $css, [
			'py-half-gutter',
			'px-gutter',
			'text-left'
		] );
	}
}
add_filter( 'tm_inbox_header_col_css', 'wp_tm_add_inbox_header_col_css' );

if ( ! function_exists( 'wp_tm_add_inbox_content_css' ) ) {
	function wp_tm_add_inbox_content_css( $css ) {
		return array_merge( $css, [
			'bg-base',
			'divide-y',
			'divide-base-200',
			'border',
			'border-t-0',
			'border-solid',
			'border-base-200'
		] );
	}
}
add_filter( 'tm_inbox_content_css', 'wp_tm_add_inbox_content_css' );

if ( ! function_exists( 'wp_tm_add_inbox_no_message_css' ) ) {
	function wp_tm_add_inbox_no_message_css( $css ) {
		return array_merge( $css, [
			'text-center',
			'py-double-gutter'
		] );
	}
}
add_filter( 'tm_inbox_no_message_css', 'wp_tm_add_inbox_no_message_css' );

if ( ! function_exists( 'wp_tm_add_inbox_row_css' ) ) {
	function wp_tm_add_inbox_row_css( $css ) {
		return array_merge( $css, [
			'odd:bg-base',
			'even:bg-base-100'
		] );
	}
}
add_filter( 'tm_inbox_row_css', 'wp_tm_add_inbox_row_css' );

if ( ! function_exists( 'wp_tm_add_inbox_link_css' ) ) {
	function wp_tm_add_inbox_link_css( $css ) {
		return array_merge( $css, [
			'hover:text-primary',
			'hover:fill-primary'
		] );
	}
}
add_filter( 'tm_inbox_link_css', 'wp_tm_add_inbox_link_css' );

/**
 * Message css
 */

if ( ! function_exists( 'wp_tm_add_message_box_css' ) ) {
	function wp_tm_add_message_box_css( $css ) {
		return array_merge( $css, [
			'bg-base',
			'border',
			'border-solid',
			'border-base-200'
		] );
	}
}
add_filter( 'tm_message_box_css', 'wp_tm_add_message_box_css' );

if ( ! function_exists( 'wp_tm_add_message_box_header_css' ) ) {
	function wp_tm_add_message_box_header_css( $css ) {
		return array_merge( $css, [
			'flex',
			'justify-between',
			'p-half-gutter',
		] );
	}
}
add_filter( 'tm_message_box_header_css', 'wp_tm_add_message_box_header_css' );
add_filter( 'tm_message_box_header_css', 'wp_tm_add_inbox_header_css' );

if ( ! function_exists( 'wp_tm_add_message_box_header_link_css' ) ) {
	function wp_tm_add_message_box_header_link_css( $css ) {
		return [
			'hover:text-primary'
		];
	}
}
add_filter( 'tm_message_box_header_link_css', 'wp_tm_add_message_box_header_link_css' );

if ( ! function_exists( 'wp_tm_add_message_subject_css' ) ) {
	function wp_tm_add_message_subject_css( $css ) {
		return array_merge( $css, [
			'font-bold',
			'my-gutter',
			'px-half-gutter',
			'text-4xl'
		] );
	}
}
add_filter( 'tm_message_subject_css', 'wp_tm_add_message_subject_css' );

if ( ! function_exists( 'wp_tm_add_message_metas_css' ) ) {
	function wp_tm_add_message_metas_css( $css ) {
		return array_merge( $css, [
			'flex',
			'justify-between',
			'items-center',
			'text-sm',
			'text-base-content/50',
			'border-dashed',
			'border-y-2',
			'border-x-0',
			'border-base-100',
			'p-half-gutter',
			'mb-gutter'
		] );
	}
}
add_filter( 'tm_message_metas_css', 'wp_tm_add_message_metas_css' );

if ( ! function_exists( 'wp_tm_add_message_content_css' ) ) {
	function wp_tm_add_message_content_css( $css ) {
		return array_merge( $css, [
			'overflow-auto',
			'p-half-gutter',
			'mt-2'
		] );
	}
}
add_filter( 'tm_message_content_css', 'wp_tm_add_message_content_css' );

/**
 * Attachments
 */

if ( ! function_exists( 'wp_tm_add_attachments_css' ) ) {
	function wp_tm_add_attachments_css( $css ) {
		return array_merge( $css, [
			'border-t',
			'text-sm',
			'border-base-100',
			'py-half-gutter',
			'space-y-2'
		] );
	}
}
add_filter( 'tm_attachments_css', 'wp_tm_add_attachments_css' );

if ( ! function_exists( 'wp_tm_add_attachments_title_css' ) ) {
	function wp_tm_add_attachments_title_css( $css ) {
		return array_merge( $css, [
			'font-bold'
		] );
	}
}
add_filter( 'tm_attachments_title_css', 'wp_tm_add_attachments_title_css' );

if ( ! function_exists( 'wp_tm_add_attachment_item_css' ) ) {
	function wp_tm_add_attachment_item_css( $css ) {
		return array_merge( $css, [
			'block',
			'p-2',
			'border',
			'border-base-100',
			'hover:bg-base-100',
			'hover:text-primary',
			'hover:fill-primary',
		] );
	}
}
add_filter( 'tm_attachment_item_css', 'wp_tm_add_attachment_item_css' );

if ( ! function_exists( 'wp_tm_add_attachment_icon_css' ) ) {
	function wp_tm_add_attachment_icon_css( $css ) {
		return array_merge( $css, [
			'inline-block'
		] );
	}
}
add_filter( 'tm_attachment_icon_css', 'wp_tm_add_attachment_icon_css' );

if ( ! function_exists( 'wp_tm_add_attachment_size_css' ) ) {
	function wp_tm_add_attachment_size_css( $css ) {
		return array_merge( $css, [
			'text-xs',
			'text-base-content/50'
		] );
	}
}
add_filter( 'tm_attachment_size_css', 'wp_tm_add_attachment_size_css' );

/**
 * Pagination css
 */

if ( ! function_exists( 'wp_tm_add_pagination_css' ) ) {
	function wp_tm_add_pagination_css( $css ) {
		return array_merge( $css, [
			'btn-group',
			'justify-center',
			'mt-gutter'
		] );
	}
}
add_filter( 'tm_pagination_css', 'wp_tm_add_pagination_css' );

if ( ! function_exists( 'wp_tm_add_pagination_item_css' ) ) {
	function wp_tm_add_pagination_item_css( $css ) {
		return array_merge( $css, [
			'btn',
			'btn-accent'
		] );
	}
}
add_filter( 'tm_pagination_item_css', 'wp_tm_add_pagination_item_css' );
add_filter( 'tm_pagination_curren_item_css', 'wp_tm_add_pagination_item_css' );
add_filter( 'tm_pagination_ellipsis_css', 'wp_tm_add_pagination_item_css' );

if ( ! function_exists( 'wp_tm_add_pagination_curren_item_css' ) ) {
	function wp_tm_add_pagination_curren_item_css( $css ) {
		return array_merge( $css, [ 'btn-active' ] );
	}
}
add_filter( 'tm_pagination_curren_item_css', 'wp_tm_add_pagination_curren_item_css' );

if ( ! function_exists( 'wp_tm_add_pagination_ellipsis_css' ) ) {
	function wp_tm_add_pagination_ellipsis_css( $css ) {
		return array_merge( $css, [ 'btn-disabled' ] );
	}
}
add_filter( 'tm_pagination_ellipsis_css', 'wp_tm_add_pagination_ellipsis_css' );

/**
 * Alert css
 */

if ( ! function_exists( 'wp_tm_add_alert_box_css' ) ) {
	function wp_tm_add_alert_box_css( $css ) {
		return array_merge( $css, [
			'flex',
			'items-center',
			'shadow',
			'border-0',
			'border-t-4',
			'border-solid',
			'p-gutter',
			'my-half-gutter',
		] );
	}
}
add_filter( 'tm_alert_box_css', 'wp_tm_add_alert_box_css' );

if ( ! function_exists( 'wp_tm_add_info_alert_box_css' ) ) {
	function wp_tm_add_info_alert_box_css( $css ) {
		return array_merge( $css, [
			'border-sky-400',
			'fill-sky-400',
			'bg-sky-50'
		] );
	}
}
add_filter( 'tm_info_alert_box_css', 'wp_tm_add_info_alert_box_css' );

if ( ! function_exists( 'wp_tm_add_success_alert_box_css' ) ) {
	function wp_tm_add_success_alert_box_css( $css ) {
		return array_merge( $css, [
			'border-emerald-400',
			'fill-emerald-400',
			'bg-emerald-50'
		] );
	}
}
add_filter( 'tm_success_alert_box_css', 'wp_tm_add_success_alert_box_css' );

if ( ! function_exists( 'wp_tm_add_warning_alert_box_css' ) ) {
	function wp_tm_add_warning_alert_box_css( $css ) {
		return array_merge( $css, [
			'border-amber-400',
			'fill-amber-400',
			'bg-amber-50'
		] );
	}
}
add_filter( 'tm_warning_alert_box_css', 'wp_tm_add_warning_alert_box_css' );

if ( ! function_exists( 'wp_tm_add_error_alert_box_css' ) ) {
	function wp_tm_add_error_alert_box_css( $css ) {
		return array_merge( $css, [
			'border-red-500',
			'fill-red-500',
			'bg-red-50'
		] );
	}
}
add_filter( 'tm_error_alert_box_css', 'wp_tm_add_error_alert_box_css' );

if ( ! function_exists( 'wp_tm_add_alert_icon_css' ) ) {
	function wp_tm_add_alert_icon_css( $css ) {
		return array_merge( $css, [
			'shrink-0',
			'mr-gutter'
		] );
	}
}
add_filter( 'tm_alert_icon_css', 'wp_tm_add_alert_icon_css' );

if ( ! function_exists( 'wp_tm_add_alert_message_css' ) ) {
	function wp_tm_add_alert_message_css( $css ) {
		return array_merge( $css, [
			'font-bold',
			'block',
			'text-base'
		] );
	}
}
add_filter( 'tm_alert_message', 'wp_tm_add_alert_message_css' );

if ( ! function_exists( 'wp_tm_add_alert_back_link_css' ) ) {
	function wp_tm_add_alert_back_link_css( $css ) {
		return array_merge( $css, [
			'text-sm',
			'underline',
			'pl-half-gutter',
			'hover:text-primary'
		] );
	}
}
add_filter( 'tm_alert_back_link_css', 'wp_tm_add_alert_back_link_css' );
