<?php

if ( !function_exists( 'wp_tm_primary_navigation_fallback' ) ) {
    /**
     * Fallback for primary navigation.
     */
    function wp_tm_primary_navigation_fallback( $args )
    {
        echo  '<ul class="' . $args['menu_class'] . '">' ;
        echo  '<li class="menu-item"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Home', 'temp-mail-x' ) . '</a></li>' ;
        wp_list_pages( array(
            'title_li' => '',
            'depth'    => 1,
            'number'   => 5,
        ) );
        echo  '</ul>' ;
    }

}
if ( !function_exists( 'wp_tm_list_archive_image_style' ) ) {
    /**
     * Dynamic css for feature image in archive page
     *
     * @return string
     */
    function wp_tm_list_archive_image_style()
    {
        if ( get_wp_tm_option( 'wp_tm_posts_layout' ) === 'archive-grid' ) {
            return '';
        }
        $width = get_wp_tm_option( 'wp_tm_archive_list_layout_image_width' );
        if ( $width <= 0 ) {
            return '';
        }
        return sprintf( 'min-width: %1$s%%; max-width: %1$s%%;', $width );
    }

}
if ( !function_exists( 'wp_tm_post_views' ) ) {
    /**
     * Gets total post views for a post
     *
     * @param int $post_id
     *
     * @return int
     */
    function wp_tm_post_views( $post_id = 0 )
    {
        if ( function_exists( 'pvc_get_post_views' ) ) {
            return pvc_get_post_views( $post_id );
        }
        return -1;
    }

}
if ( !function_exists( 'wp_tm_render_attributes' ) ) {
    /**
     * Render html attributes
     *
     * @param $attributes
     */
    function wp_tm_render_attributes( $attributes )
    {
        $attrArr = array();
        foreach ( $attributes as $key => $value ) {
            $attrArr[] = $key . '="' . esc_attr( $value ) . '"';
        }
        // PHPCS - the output hold safe data.
        echo  implode( ' ', $attrArr ) ;
        // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    }

}
if ( !function_exists( 'wp_tm_clsx' ) ) {
    /**
     * A utility for constructing className strings conditionally.
     *
     * @return string
     */
    function wp_tm_clsx( ... $args )
    {
        $classNames = array();
        foreach ( $args as $arg ) {
            
            if ( is_string( $arg ) ) {
                $classNames[] = $arg;
            } else {
                if ( is_array( $arg ) ) {
                    foreach ( $arg as $k => $v ) {
                        
                        if ( is_string( $v ) ) {
                            $classNames[] = $v;
                        } else {
                            if ( is_bool( $v ) && $v === true ) {
                                $classNames[] = $k;
                            }
                        }
                    
                    }
                }
            }
        
        }
        return esc_attr( implode( ' ', $classNames ) );
    }

}
if ( !function_exists( 'wp_tm_clsx_echo' ) ) {
    /**
     * Echo version for wp_tm_clsx
     *
     * @param ...$args
     */
    function wp_tm_clsx_echo( ... $args )
    {
        echo  wp_tm_clsx( ...$args ) ;
    }

}
if ( !function_exists( 'wp_tm_is_hero_visible' ) ) {
    /**
     * Return is hero section visible
     *
     * @return bool
     */
    function wp_tm_is_hero_visible()
    {
        return is_front_page() && !is_home() && get_wp_tm_option( 'wp_tm_show_frontpage_hero' );
    }

}
if ( !function_exists( 'wp_tm_is_inbox_visible' ) ) {
    /**
     * Return is hero section visible
     *
     * @return bool
     */
    function wp_tm_is_inbox_visible()
    {
        return is_front_page() && !is_home() && get_wp_tm_option( 'wp_tm_show_frontpage_inbox' );
    }

}
if ( !function_exists( 'wp_tm_is_frontpage_header' ) ) {
    /**
     *
     */
    function wp_tm_is_frontpage_header()
    {
        return is_front_page() && !is_home();
    }

}
if ( !function_exists( 'wp_tm_custom_logo' ) ) {
    /**
     * Get custom logo.
     */
    function wp_tm_custom_logo()
    {
        $is_frontpage_transparent_navbar = wp_tm_is_frontpage_header() && get_wp_tm_frontpage_header_style() === 'navbar-transparent';
        $main_logo = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
        if ( !empty($main_logo) && is_array( $main_logo ) ) {
            $main_logo = $main_logo[0];
        }
        $transparent_logo = wp_get_attachment_image_src( get_wp_tm_option( 'wp_tm_transparent_header_logo' ), 'full' );
        if ( !empty($transparent_logo) && is_array( $transparent_logo ) ) {
            $transparent_logo = $transparent_logo[0];
        }
        $transparent_reverse_logo = wp_get_attachment_image_src( get_wp_tm_option( 'wp_tm_transparent_reverse_header_logo' ), 'full' );
        if ( !empty($transparent_reverse_logo) && is_array( $transparent_reverse_logo ) ) {
            $transparent_reverse_logo = $transparent_reverse_logo[0];
        }
        // show transparent logo
        
        if ( $is_frontpage_transparent_navbar && empty($transparent_logo) === false ) {
            $attachment_id = attachment_url_to_postid( $transparent_logo );
            $alt_attribute = get_post_meta( $attachment_id, '_wp_attachment_image_alt', true );
            $alt_attribute = ( !empty($alt_attribute) ? $alt_attribute : get_bloginfo( 'name' ) );
            echo  '<img class="wp-tm-transparent-logo" src="' . esc_url( $transparent_logo ) . '" alt="' . esc_attr( $alt_attribute ) . '" />' ;
            
            if ( empty($transparent_reverse_logo) === false ) {
                echo  '<img class="wp-tm-transparent-reverse-logo" src="' . esc_url( $transparent_reverse_logo ) . '" alt="' . esc_attr( $alt_attribute ) . '" />' ;
                return;
            }
        
        }
        
        $custom_logo_css = wp_tm_clsx( array( 'font-bold', 'wp-tm-custom-logo' => empty($transparent_logo) === false ) );
        // show default logo
        
        if ( empty($main_logo) === false ) {
            $alt_attribute = get_post_meta( get_theme_mod( 'custom_logo' ), '_wp_attachment_image_alt', true );
            $alt_attribute = ( !empty($alt_attribute) ? $alt_attribute : get_bloginfo( 'name' ) );
            echo  '<img class="' . $custom_logo_css . '" src="' . esc_url( $main_logo ) . '" alt="' . esc_attr( $alt_attribute ) . '" />' ;
            return;
        }
        
        // show text logo
        echo  '<span class="' . $custom_logo_css . '">' . get_wp_tm_option( 'wp_tm_text_logo' ) . '</span>' ;
    }

}
if ( !function_exists( 'wp_tm_hero_section_content' ) ) {
    /**
     * Show hero content
     */
    function wp_tm_hero_section_content()
    {
        $content_type = get_wp_tm_option( 'wp_tm_hero_content_type' );
        
        if ( $content_type === 'mailbox' ) {
            get_template_part( 'template-parts/frontpage', 'hero-mailbox' );
        } else {
            get_template_part( 'template-parts/frontpage', 'hero-simple' );
        }
    
    }

}
if ( !function_exists( 'wp_tm_render_image_radio' ) ) {
    /**
     * Render image radio.
     *
     * @param array $args
     * @param \Closure $callback
     * @param array $callback_args
     *
     * @return string
     */
    function wp_tm_render_image_radio( $args, $callback, $callback_args = array() )
    {
        $defaults = [
            'id'       => '',
            'name'     => '',
            'selected' => 0,
            'echo'     => true,
        ];
        $r = wp_parse_args( $args, $defaults );
        $output = '';
        $choices = array();
        if ( is_callable( $callback ) ) {
            $choices = call_user_func_array( $callback, $callback_args );
        }
        
        if ( !empty($choices) ) {
            $output = '<div id="' . $r['id'] . '" class="wp-tm-image-radio-button-control">';
            foreach ( $choices as $key => $choice ) {
                $output .= '<label class="radio-button-label">';
                $output .= '<input type="radio" id="' . $r['id'] . $key . '" name="' . $r['name'] . '" value="' . $key . '" ';
                $output .= checked( $r['selected'], $key, false );
                $output .= '/>';
                $output .= '<img src="' . $choice['image'] . '" alt="' . $choice['name'] . '" title="' . $choice['name'] . '"/>';
                $output .= '</label>';
            }
            $output .= "</div>\n";
        }
        
        if ( $r['echo'] ) {
            echo  $output ;
        }
        return $output;
    }

}
if ( !function_exists( 'wp_tm_render_select_dropdown' ) ) {
    /**
     * Render select dropdown.
     *
     * @param array $args
     * @param \Closure $callback
     * @param array $callback_args
     *
     * @return string
     */
    function wp_tm_render_select_dropdown( $args, $callback, $callback_args = array() )
    {
        $defaults = [
            'id'          => '',
            'name'        => '',
            'selected'    => 0,
            'echo'        => true,
            'add_default' => false,
        ];
        $r = wp_parse_args( $args, $defaults );
        $output = '';
        $choices = array();
        if ( is_callable( $callback ) ) {
            $choices = call_user_func_array( $callback, $callback_args );
        }
        
        if ( !empty($choices) || true === $r['add_default'] ) {
            $output = "<select name='" . esc_attr( $r['name'] ) . "' id='" . esc_attr( $r['id'] ) . "'>\n";
            if ( true === $r['add_default'] ) {
                $output .= '<option value="">' . esc_html__( 'Default', 'temp-mail-x' ) . '</option>\\n';
            }
            if ( !empty($choices) ) {
                foreach ( $choices as $key => $choice ) {
                    $output .= '<option value="' . esc_attr( $key ) . '" ';
                    $output .= selected( $r['selected'], $key, false );
                    $output .= '>' . esc_html( $choice ) . '</option>\\n';
                }
            }
            $output .= "</select>\n";
        }
        
        if ( $r['echo'] ) {
            echo  $output ;
        }
        return $output;
    }

}