<?php

if ( ! function_exists( 'wp_tm_post_meta' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function wp_tm_post_meta( $items = array( 'posted_on', 'views', 'comments' ) ) {
		$link_class = 'link link-hover-primary no-underline';

		foreach ( $items as $item ) {

			if ( $item === 'byline' ) {

				$byline = sprintf(
					'%s',
					'<i class="fas fa-pen-nib mr-1.5"></i><a class="' . $link_class . '" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
				);

				if ( ! empty( $byline ) ) {
					echo '<span class="mr-3 byline meta-item"> ' . $byline . '</span>';
				}
			} elseif ( $item === 'posted_on' ) {
				$time_string = '<time class="published updated" datetime="%1$s">%2$s</time>';
				if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
					$time_string = '<time class="published" datetime="%1$s">%2$s</time><time class="updated hidden" datetime="%3$s">%4$s</time>';
				}

				$time_string = sprintf( $time_string,
					esc_attr( get_the_date( 'c' ) ),
					esc_html( get_the_date( 'Y/m/d' ) ),
					esc_attr( get_the_modified_date( 'c' ) ),
					esc_html( get_the_modified_date( 'Y/m/d' ) )
				);

				$posted_on = sprintf(
					'%s',
					'<a class="' . $link_class . '" href="' . esc_url( get_permalink() ) . '" rel="bookmark"><span class="entry-date">' . $time_string . '</span></a>'
				);

				if ( ! empty( $posted_on ) ) {
					echo '<span class="posted-on meta-item mr-3"><i class="far fa-clock mr-1.5"></i>' . $posted_on . '</span>';
				}
			} elseif ( $item === 'views' ) {
				$views = wp_tm_post_views();
				if ( $views >= 0 ) {
					echo '<span class="mr-3 meta-item views"><i class="far fa-eye mr-1.5"></i>' . $views . '</span>';
				}
			} elseif ( $item === 'comments' && comments_open( get_the_ID() ) ) {
				echo '<span class="mr-3 meta-item comments-link">';
				echo '<i class="far fa-comments mr-1.5"></i>';
				comments_popup_link( '0', '1', '%', $link_class );
				echo '</span>';
			} elseif ( $item === 'tags' ) {
				wp_tm_post_tags( '<span class="meta-item">', '</span>' );
			}
		}
	}
}

if ( ! function_exists( 'wp_tm_post_tags' ) ) {
	/**
	 * Prints HTML with tags information for the current post.
	 */
	function wp_tm_post_tags( $before = '', $after = '' ) {
		// Hide tag text for pages.
		if ( 'post' !== get_post_type() ) {
			return;
		}

		$tags = get_the_tags();

		if ( is_wp_error( $tags ) || empty( $tags ) ) {
			return;
		}

		$tag_links = array_map( function ( $tag ) {
			return '<a class="link link-hover-primary" href="' . esc_url( get_tag_link( $tag->term_id ) ) . '" rel="tag">' . $tag->name . '</a>';
		}, $tags );

		$before .= '<i class="text-xs fas fa-tags mr-1.5"></i>';

		/* Translators: used between list items, there is a space after the comma. */
		echo $before . implode( esc_html__( ', ', 'temp-mail-x' ), $tag_links ) . $after;
	}
}

if ( ! function_exists( 'wp_tm_post_categories' ) ) {
	/**
	 * Prints HTML with categories information for the current post.
	 */
	function wp_tm_post_categories( $before = '', $after = '', $style = '' ) {
		// Hide category for pages.
		if ( 'post' !== get_post_type() || empty( get_the_category() ) ) {
			return;
		}

		global $wp_rewrite;

		$rel = ( is_object( $wp_rewrite ) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';
		echo $before;
		foreach ( get_the_category() as $category ) {
			echo '<a class="' . $style . '" href="' . esc_url( get_category_link( $category->term_id ) ) . '" ' . $rel . '>' . $category->name . '</a>';
		}
		echo $after;
	}
}

if ( ! function_exists( 'wp_tm_categorized_blog' ) ) {
	/**
	 * Returns true if a blog has more than 1 category.
	 *
	 * @return bool
	 */
	function wp_tm_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'wp_tm_categories' ) ) ) {
			// Create an array of all the categories that are attached to posts.
			$all_the_cool_cats = get_categories( [
				'fields' => 'ids',

				// We only need to know if there is more than one category.
				'number' => 2,
			] );

			// Count the number of categories that are attached to the posts.
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'wp_tm_categories', $all_the_cool_cats );
		}

		if ( $all_the_cool_cats > 1 ) {
			// This blog has more than 1 category so wp_tm_categorized_blog should return true.
			return true;
		} else {
			// This blog has only 1 category so wp_tm_categorized_blog should return false.
			return false;
		}
	}
}
