<?php

/**
 * Theme Filters
 */

if ( ! function_exists( 'wp_tm_get_theme_attributes' ) ) {
	/**
	 * Get current theme data
	 *
	 * @return string
	 */
	function wp_tm_get_theme_attributes() {
		$theme = apply_filters( 'wp_tm_filter_theme', '' );

		return 'data-theme="' . $theme . '"';
	}
}

if ( ! function_exists( 'wp_tm_get_header_class' ) ) {
	/**
	 * Get header class.
	 *
	 * @return string
	 */
	function wp_tm_get_header_class() {
		$header_class = apply_filters( 'wp_tm_filter_header_class', [] );

		return implode( ' ', $header_class );
	}
}

/**
 * Apply filters
 */

if ( ! function_exists( 'wp_tm_custom_body_class' ) ) {
	/**
	 * Custom body class.
	 *
	 * @param string|array $input
	 *
	 * @return array Array of classes.
	 */
	function wp_tm_custom_body_class( $input ) {

		// global style
		$input = array_merge( $input, [
			'w-full',
			'h-full',
			'min-h-screen',
			'text-base-content',
			'bg-base-100',
		] );

		// Adds a class of group-blog to blogs with more than 1 published author.
		if ( is_multi_author() ) {
			$input[] = 'group-blog';
		}

		return $input;
	}
}
add_filter( 'body_class', 'wp_tm_custom_body_class' );

if ( ! function_exists( 'wp_tm_header_class' ) ) {
	/**
	 * Custom header class.
	 *
	 * @param string|array $input
	 *
	 * @return array Array of classes.
	 */
	function wp_tm_header_class( $input ) {
		if ( wp_tm_is_hero_visible() ) {
			$input[] = 'absolute w-full z-50';
		}

		return $input;
	}
}
add_filter( 'wp_tm_filter_header_class', 'wp_tm_header_class' );

if ( ! function_exists( 'wp_tm_excerpt_length' ) ) {
	/**
	 * Sets the post excerpt length to n words.
	 *
	 * function tied to the excerpt_length filter hook.
	 * @uses filter excerpt_length
	 */
	function wp_tm_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}

		// Getting data from Customizer Options
		return absint( get_wp_tm_option( 'wp_tm_excerpt_length' ) );
	}
}
add_filter( 'excerpt_length', 'wp_tm_excerpt_length', 999 );

if ( ! function_exists( 'wp_tm_excerpt_more' ) ) {
	/**
	 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a option from customizer
	 *
	 * @return string option from customizer prepended with an ellipsis.
	 */
	function wp_tm_excerpt_more( $link ) {
		if ( is_admin() ) {
			return $link;
		}

		return wp_tm_get_theme_mod( 'wp_tm_excerpt_more_text', '...' );
	}
}
add_filter( 'excerpt_more', 'wp_tm_excerpt_more' );

if ( ! function_exists( 'wp_tm_list_pages_filter' ) ) {
	/**
	 * add classes to wp_list_pages
	 */
	function wp_tm_list_pages_filter( $output ) {
		$output = str_replace( 'page_item', 'page_item menu-item', $output );

		return $output;
	}
}
add_filter( 'wp_list_pages', 'wp_tm_list_pages_filter' );
