<?php

/**
 * Document structure hooks
 */
if ( !function_exists( 'wp_tm_doctype' ) ) {
    /**
     * Doctype declaration.
     */
    function wp_tm_doctype()
    {
        $clsx = apply_filters( 'wp_tm_filter_html_class', [] );
        echo  '<!DOCTYPE html><html ' . get_language_attributes() . ' ' . wp_tm_get_theme_attributes() . ' class="' . implode( ' ', $clsx ) . '">' ;
    }

}
add_action( 'wp_tm_action_doctype', 'wp_tm_doctype', 10 );
if ( !function_exists( 'wp_tm_head' ) ) {
    /**
     * Head tags.
     */
    function wp_tm_head()
    {
        ?>
        <meta charset="<?php 
        bloginfo( 'charset' );
        ?>">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta http-equiv="X-UA-Compatible" content="ie=edge">
        <link rel="profile" href="http://gmpg.org/xfn/11">
		<?php 
        
        if ( is_singular() && pings_open() ) {
            ?>
            <link rel="pingback" href="<?php 
            bloginfo( 'pingback_url' );
            ?>">
		<?php 
        }
    
    }

}
add_action( 'wp_tm_action_head', 'wp_tm_head' );
if ( !function_exists( 'wp_tm_add_preloader' ) ) {
    /**
     * Add preloader
     */
    function wp_tm_add_preloader()
    {
        if ( wp_tm_get_theme_mod( 'wp_tm_disable_preloader' ) === true ) {
            return;
        }
        get_template_part( 'template-parts/preloader' );
    }

}
add_action( 'wp_tm_action_before', 'wp_tm_add_preloader' );
/**
 * Header area hook
 */
if ( !function_exists( 'wp_tm_add_header_open' ) ) {
    function wp_tm_add_header_open()
    {
        ?>
        <header class="<?php 
        echo  esc_attr( wp_tm_get_header_class() ) ;
        ?>">
		<?php 
    }

}
add_action( 'wp_tm_action_before_header', 'wp_tm_add_header_open' );
if ( !function_exists( 'wp_tm_add_primary_navbar' ) ) {
    /**
     * Add primary navbar.
     */
    function wp_tm_add_primary_navbar()
    {
        get_template_part( 'template-parts/header', 'navbar' );
    }

}
add_action( 'wp_tm_action_header', 'wp_tm_add_primary_navbar', 30 );
if ( !function_exists( 'wp_tm_add_header_close' ) ) {
    function wp_tm_add_header_close()
    {
        ?>
        </header>
		<?php 
    }

}
add_action( 'wp_tm_action_after_header', 'wp_tm_add_header_close' );
if ( !function_exists( 'wp_tm_add_search_modal' ) ) {
    function wp_tm_add_search_modal()
    {
        if ( get_wp_tm_option( 'wp_tm_show_header_search' ) ) {
            get_template_part( 'template-parts/header', 'search-modal' );
        }
    }

}
add_action( 'wp_tm_action_after_header', 'wp_tm_add_search_modal' );
if ( !function_exists( 'wp_tm_add_frontpage_hero' ) ) {
    /**
     * Add hero section to frontpage
     */
    function wp_tm_add_frontpage_hero()
    {
        if ( wp_tm_is_hero_visible() ) {
            get_template_part( 'template-parts/frontpage', 'hero' );
        }
    }

}
add_action( 'wp_tm_action_after_header', 'wp_tm_add_frontpage_hero', 40 );
if ( !function_exists( 'wp_tm_add_frontpage_inbox' ) ) {
    /**
     * Add inbox section to frontpage
     */
    function wp_tm_add_frontpage_inbox()
    {
        if ( wp_tm_is_inbox_visible() ) {
            get_template_part( 'template-parts/frontpage', 'inbox' );
        }
    }

}
add_action( 'wp_tm_action_after_header', 'wp_tm_add_frontpage_inbox', 40 );
/**
 * Content & sidebar hooks
 */
if ( !function_exists( 'wp_tm_add_primary_sidebar' ) ) {
    /**
     * Add primary sidebar.
     */
    function wp_tm_add_primary_sidebar( $layout )
    {
        // Include primary sidebar.
        if ( 'no-sidebar' !== $layout ) {
            get_sidebar();
        }
    }

}
add_action( 'wp_tm_action_sidebar', 'wp_tm_add_primary_sidebar' );
if ( !function_exists( 'wp_tm_show_post_content' ) ) {
    /**
     * Show post content.
     */
    function wp_tm_show_post_content()
    {
        get_template_part( 'template-parts/content', 'single' );
    }

}
add_action( 'wp_tm_action_single_post', 'wp_tm_show_post_content' );
if ( !function_exists( 'wp_tm_show_page_content' ) ) {
    /**
     * Show page content.
     */
    function wp_tm_show_page_content()
    {
        get_template_part( 'template-parts/content', 'page' );
    }

}
add_action( 'wp_tm_action_page', 'wp_tm_show_page_content' );
if ( !function_exists( 'wp_tm_add_post_navigation' ) ) {
    /**
     * Add post navigation.
     */
    function wp_tm_add_post_navigation()
    {
        the_post_navigation( [
            'prev_text'          => '<i class="text-sm fa fa-angle-double-left"></i><span class="px-half-gutter">%title</span>',
            'next_text'          => '<span class="px-half-gutter">%title</span><i class="text-sm fa fa-angle-double-right"></i>',
            'screen_reader_text' => '<span class="nav-subtitle screen-reader-text">' . esc_html__( 'Page', 'temp-mail-x' ) . '</span>',
            'class'              => 'post-navigation',
        ] );
    }

}
add_action( 'wp_tm_action_after_single_post', 'wp_tm_add_post_navigation', 10 );
if ( !function_exists( 'wp_tm_add_after_posts_widget_area' ) ) {
    /**
     * Add after posts widget area
     */
    function wp_tm_add_after_posts_widget_area()
    {
        
        if ( is_active_sidebar( 'sidebar-after-posts-widget-area' ) ) {
            echo  '<div id="sidebar-after-posts-widget-area" class="widgets mt-4 py-half-gutter">' ;
            dynamic_sidebar( 'sidebar-after-posts-widget-area' );
            echo  '</div>' ;
        }
    
    }

}
add_action( 'wp_tm_action_after_single_post', 'wp_tm_add_after_posts_widget_area', 20 );
if ( !function_exists( 'wp_tm_add_comments' ) ) {
    /**
     * Add post comments.
     */
    function wp_tm_add_comments()
    {
        // If comments are open or we have at least one comment, load up the comment template.
        if ( comments_open() || get_comments_number() ) {
            comments_template();
        }
    }

}
add_action( 'wp_tm_action_after_single_post', 'wp_tm_add_comments', 30 );
add_action( 'wp_tm_action_after_page', 'wp_tm_add_comments' );
if ( !function_exists( 'wp_tm_custom_posts_pagination' ) ) {
    /**
     * Posts navigation.
     */
    function wp_tm_custom_posts_pagination()
    {
        global  $wp_query ;
        // Don't print empty markup in archives if there's only one page.
        if ( $wp_query->max_num_pages < 2 && (is_home() || is_archive() || is_search()) ) {
            return;
        }
        $navigation_args = [
            'class'              => 'my-gutter',
            'prev_text'          => '<span><i class="fa fa-angle-double-left"></i></span>',
            'next_text'          => '<span><i class="fa fa-angle-double-right"></i></span>',
            'screen_reader_text' => '<span class="nav-subtitle screen-reader-text">' . esc_html__( 'Page', 'temp-mail-x' ) . ' </span>',
        ];
        $pagination_type = get_wp_tm_option( 'wp_tm_pagination_type' );
        echo  '<div class="px-half-gutter mb-20">' ;
        
        if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) || class_exists( 'Catch_Infinite_Scroll' ) ) {
            // Support infinite scroll plugins.
            $navigation = get_the_posts_navigation( $navigation_args );
        } elseif ( 'numeric' === $pagination_type && function_exists( 'the_posts_pagination' ) ) {
            $navigation = get_the_posts_pagination( $navigation_args );
        } else {
            $navigation = get_the_posts_navigation( $navigation_args );
        }
        
        $navigation = str_replace( array(
            'nav-links',
            'page-numbers',
            'nav-previous',
            'nav-next',
            'current',
            'dots'
        ), array(
            'btn-group justify-center',
            'btn btn-md ' . get_wp_tm_pagination_style(),
            'btn btn-md ' . get_wp_tm_pagination_style(),
            'btn btn-md ' . get_wp_tm_pagination_style(),
            'btn-active',
            'btn-disabled'
        ), $navigation );
        echo  $navigation ;
        echo  '</div>' ;
    }

}
add_action( 'wp_tm_action_posts_pagination', 'wp_tm_custom_posts_pagination' );
/**
 * Footer area hooks
 */
if ( !function_exists( 'wp_tm_add_footer_widgets' ) ) {
    /**
     * Add footer widgets.
     */
    function wp_tm_add_footer_widgets()
    {
        get_template_part( 'template-parts/footer', 'widgets' );
    }

}
add_action( 'wp_tm_action_before_footer', 'wp_tm_add_footer_widgets', 10 );
if ( !function_exists( 'wp_tm_footer_start' ) ) {
    /**
     * Footer start.
     */
    function wp_tm_footer_start()
    {
        // Check if footer is disabled.
        if ( true !== apply_filters( 'wp_tm_filter_footer_status', true ) ) {
            return;
        }
        echo  '<footer class="text-sm border-t ' . get_wp_tm_footer_style() . '">' ;
        echo  '<div class="container mx-auto py-gutter text-center">' ;
    }

}
add_action( 'wp_tm_action_before_footer', 'wp_tm_footer_start', 20 );
if ( !function_exists( 'wp_tm_footer_end' ) ) {
    /**
     * Footer end.
     */
    function wp_tm_footer_end()
    {
        // Check if footer is disabled.
        if ( true !== apply_filters( 'wp_tm_filter_footer_status', true ) ) {
            return;
        }
        echo  '</div></footer>' ;
    }

}
add_action( 'wp_tm_action_after_footer', 'wp_tm_footer_end' );
if ( !function_exists( 'wp_tm_footer_menu' ) ) {
    function wp_tm_footer_menu()
    {
        // Check if footer is disabled.
        if ( true !== apply_filters( 'wp_tm_filter_footer_status', true ) ) {
            return;
        }
        
        if ( has_nav_menu( 'footer' ) ) {
            $footer_style = get_wp_tm_option( 'wp_tm_footer_style' );
            $clsx = array( 'pb-4 menu menu-horizontal menu-segment clearfix', 'menu-links menu-primary' => $footer_style !== 'primary' && $footer_style !== 'secondary', 'menu-underline' => $footer_style === 'primary' || $footer_style === 'secondary' );
            wp_nav_menu( array(
                'theme_location'  => 'footer',
                'container'       => 'div',
                'container_class' => 'flex justify-center',
                'depth'           => 1,
                'menu_class'      => wp_tm_clsx( $clsx ),
                'fallback_cb'     => false,
            ) );
        }
    
    }

}
add_action( 'wp_tm_action_footer', 'wp_tm_footer_menu', 10 );
if ( !function_exists( 'wp_tm_footer_copyright' ) ) {
    /**
     * Footer copyright.
     */
    function wp_tm_footer_copyright()
    {
        // Check if footer is disabled.
        if ( true !== apply_filters( 'wp_tm_filter_footer_status', true ) ) {
            return;
        }
        // Copyright content.
        $copyright_text = get_wp_tm_option( 'wp_tm_copyright_text' );
        ?>
		<?php 
        
        if ( !empty($copyright_text) ) {
            ?>
            <div class="px-half-gutter inline-block">
				<?php 
            echo  wp_kses_post( $copyright_text ) ;
            ?>
            </div>
		<?php 
        }
    
    }

}
add_action( 'wp_tm_action_footer', 'wp_tm_footer_copyright', 20 );
if ( !function_exists( 'wp_tm_footer_credits' ) ) {
    /**
     * Footer credits
     */
    function wp_tm_footer_credits()
    {
        // Check if footer is disabled.
        if ( true !== apply_filters( 'wp_tm_filter_footer_status', true ) ) {
            return;
        }
        ?>
        <div class="px-half-gutter inline-block">
			<?php 
        $theme_data = wp_get_theme();
        $site_info = sprintf(
            /* translators: 1: Site Title with home URL, 2: Privacy Policy Link  */
            _x( '%1$s %2$s', '1: Site Title with home URL, 2: Privacy Policy Link', 'temp-mail-x' ),
            '<a class="link" href="' . esc_url( home_url( '/' ) ) . '">' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>',
            ( function_exists( 'get_the_privacy_policy_link' ) ? get_the_privacy_policy_link() : '' )
        );
        $theme_info = '<span class="sep"> | </span>' . '<a class="link" target="_blank" href="' . esc_url( $theme_data->get( 'ThemeURI' ) ) . '">' . esc_html( $theme_data->get( 'Name' ) ) . '</a>' . '&nbsp;' . esc_html__( 'by', 'temp-mail-x' ) . '&nbsp;<a class="link" target="_blank" href="' . esc_url( $theme_data->get( 'AuthorURI' ) ) . '">' . esc_html( $theme_data->get( 'Author' ) ) . '</a>';
        echo  $site_info . $theme_info ;
        ?>
        </div>
		<?php 
    }

}
add_action( 'wp_tm_action_footer', 'wp_tm_footer_credits', 30 );
if ( !function_exists( 'wp_tm_add_to_top' ) ) {
    /**
     * To top button.
     */
    function wp_tm_add_to_top()
    {
        
        if ( get_wp_tm_option( 'wp_tm_show_to_top' ) ) {
            $clsx = array(
                'z-50',
                'fixed',
                'bottom-double-gutter',
                'h-[40px]',
                'w-[40px]',
                'flex',
                'items-center',
                'justify-center',
                'bg-accent',
                'text-accent-content',
                'hover:bg-primary',
                'hover:text-primary-content',
                'shadow'
            );
            $clsx[] = ( is_rtl() ? 'left-double-gutter' : 'right-double-gutter' );
            echo  '<a href="#" id="scroll-top" class="' . wp_tm_clsx( $clsx ) . '"><i class="fa fa-angle-up"></i></a>' ;
        }
    
    }

}
add_action( 'wp_tm_action_footer', 'wp_tm_add_to_top' );