<?php
/**
 * Template part for navbar in header.
 *
 * @package Temp Mail
 */

$nav_style    = array( 'navbar', 'py-0', 'relative', 'z-10' );
$menu_style   = array( 'menu menu-sm' );
$attr         = '';
$show_title   = get_wp_tm_option( 'wp_tm_show_header_title' );
$show_tagline = get_wp_tm_option( 'wp_tm_show_header_tagline' );
$button_style = [ 'btn btn-sm' ];

if ( wp_tm_is_frontpage_header() ) {
	$nav_style[]    = get_wp_tm_frontpage_header_style();
	$menu_style[]   = get_wp_tm_frontpage_header_menu_style();
	$button_style[] = wp_tm_get_button_style_css(
		get_wp_tm_option( 'wp_tm_frontpage_header_style' )
	);
} else {
	$nav_style[]    = get_wp_tm_header_style();
	$menu_style[]   = get_wp_tm_header_menu_style();
	$button_style[] = wp_tm_get_button_style_css(
		get_wp_tm_option( 'wp_tm_header_style' )
	);
}

if ( ! in_array( 'navbar-transparent', $nav_style ) ) {
	$nav_style[] = 'shadow-sm';
}

if ( get_wp_tm_option( 'wp_tm_sticky_header' ) ) {
	$attr .= 'data-sticky=' . ( is_admin_bar_showing() ? '32' : '0' ) . '';
	$attr .= ' data-sticky-z-index=30';
}
?>

<nav <?php echo esc_attr( $attr ); ?> class="<?php wp_tm_clsx_echo( $nav_style ); ?>">
    <div class="container mx-auto px-half-gutter min-h-[68px]">
        <div class="site-brand navbar-start flex items-center">
			<?php if ( get_wp_tm_option( 'wp_tm_header_brand' ) ): ?>
                <a class="block" href="<?php echo esc_url( home_url( '/' ) ) ?>"><?php wp_tm_custom_logo(); ?></a>
			<?php endif; ?>
			<?php if ( $show_title || $show_tagline ): ?>
                <div class="px-half-gutter">
					<?php if ( $show_title ): ?>
                        <span class="block font-bold uppercase"><?php bloginfo( 'name' ); ?></span>
					<?php endif; ?>
					<?php if ( $show_tagline ): ?>
                        <span class="block m-0 text-xs"><?php bloginfo( 'description' ); ?></span>
					<?php endif; ?>
                </div>
			<?php endif; ?>
        </div>

        <div class="flex-grow flex navbar-end">
			<?php
			wp_nav_menu(
				array(
					'theme_location' => 'primary',
					'menu_class'     => wp_tm_clsx( array_merge(
						array( 'menu-horizontal hidden lg:flex', 'menu-dropdown-right' => is_rtl() ),
						$menu_style
					) ),
					'container'      => '',
					'fallback_cb'    => 'wp_tm_primary_navigation_fallback',
				)
			);
			?>
            <!-- /.primary-menu -->

            <div class="flex items-center space-x-2">

				<?php if ( get_wp_tm_option( 'wp_tm_show_header_search' ) ): ?>
                    <button id="nav-search-toggle" data-toggle="toggle" data-toggle-target="#search-modal"
                            data-toggle-show-focus="#search-modal :focusable"
                            type="button"
                            class="nav-search-button btn btn-sm">
                        <i class="fas fa-search"></i>
                        <span class="screen-reader-text"><?php esc_html_e( 'Search Modal Toggle', 'temp-mail-x' ); ?></span>
                    </button>
				<?php endif; ?>

                <button id="mobile-menu-toggle" class="navbar-toggle lg:hidden" data-toggle="collapse"
                        data-toggle-target=".mobile-menu-wrap"
                        aria-expanded="false">
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="sr-only"><?php esc_html_e( 'Toggle Toggle', 'temp-mail-x' ); ?></span>
                </button>
            </div>
        </div>
    </div>

    <nav data-redirect-focus="#mobile-menu-toggle"
         class="not-flex mobile-menu-wrap container mx-auto px-half-gutter hidden"
         aria-expanded="false">
		<?php
		wp_nav_menu(
			array(
				'theme_location' => 'primary',
				'menu_class'     => wp_tm_clsx( array_merge(
					array( 'menu-vertical lg:hidden pb-4' ),
					$menu_style
				) ),
				'container'      => '',
				'fallback_cb'    => 'wp_tm_primary_navigation_fallback',
			)
		);
		?>
        <!-- .primary-menu-mobile -->
    </nav>
</nav>